==> ontoTools_1.28.0.zip: ontoTools/doc/sgdiOnto.R <==
###################################################
### chunk number 1: 
###################################################
#line 88 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmplGErpx/R.INSTALL7b604cf1/ontoTools/inst/doc/sgdiOnto.Rnw"
options(width=70)
require(ontoTools, quietly=TRUE)
library(KEGG.db)
#require(KEGG, quietly=TRUE)


###################################################
### chunk number 2: keggdemo
###################################################
#line 93 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmplGErpx/R.INSTALL7b604cf1/ontoTools/inst/doc/sgdiOnto.Rnw"
KPL <- eapply(KEGGPATHID2NAME, function(x)x)
GDI_KEGGPATH <- new("nomenclature", name="KEGGPATH",
 provenance=new("provStruct", 
 URI="ftp://ftp.genome.ad.jp/pub/kegg/pathways/map_title.tab", 
 captureDate="June 30 2004", comment="Rel 30.0"), 
 inMappings=c("LL2KEGGmap.hsa", "LL2KEGGmap.rno"),
 terms=names(KPL), definitions=as.character(unlist(KPL)))
GDI_KEGGPATH


###################################################
### chunk number 3: lkGDINCI
###################################################
#line 129 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmplGErpx/R.INSTALL7b604cf1/ontoTools/inst/doc/sgdiOnto.Rnw"
data(GDI_NCIThesaurus)
GDI_NCIThesaurus


###################################################
### chunk number 4: lkpar
###################################################
#line 135 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmplGErpx/R.INSTALL7b604cf1/ontoTools/inst/doc/sgdiOnto.Rnw"
mpar <- parents("Mesna", GDI_NCIThesaurus)
mpar
children( mpar, GDI_NCIThesaurus )


###################################################
### chunk number 5: lkHER
###################################################
#line 141 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmplGErpx/R.INSTALL7b604cf1/ontoTools/inst/doc/sgdiOnto.Rnw"
substring(grep("HER-2", GDI_NCIThesaurus),1,70)


###################################################
### chunk number 6: lkdef
###################################################
#line 145 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmplGErpx/R.INSTALL7b604cf1/ontoTools/inst/doc/sgdiOnto.Rnw"
getDefs("Mesna", GDI_NCIThesaurus)


###################################################
### chunk number 7: 
###################################################
#line 178 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmplGErpx/R.INSTALL7b604cf1/ontoTools/inst/doc/sgdiOnto.Rnw"
data(SGDIvocab)
SGDIvocab@terms


###################################################
### chunk number 8: loadRswub eval=FALSE
###################################################
## #line 224 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmplGErpx/R.INSTALL7b604cf1/ontoTools/inst/doc/sgdiOnto.Rnw"
## library(Rswub)


###################################################
### chunk number 9: useRswub eval=FALSE
###################################################
## #line 226 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmplGErpx/R.INSTALL7b604cf1/ontoTools/inst/doc/sgdiOnto.Rnw"
## omod <- readSWModel("http://www.biostat.harvard.edu/~carey/SGDI.owl", asURL=TRUE)


###################################################
### chunk number 10: local eval=FALSE
###################################################
## #line 228 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmplGErpx/R.INSTALL7b604cf1/ontoTools/inst/doc/sgdiOnto.Rnw"
## omod <- readSWModel("/home/stvjc/Protege_3.0_beta/SGDI.owl")
## omod@documentName <- "http://www.biostat.harvard.edu/~carey/SGDI.owl"


###################################################
### chunk number 11: lkmod eval=FALSE
###################################################
## #line 232 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmplGErpx/R.INSTALL7b604cf1/ontoTools/inst/doc/sgdiOnto.Rnw"
## omod


###################################################
### chunk number 12: lkont eval=FALSE
###################################################
## #line 250 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmplGErpx/R.INSTALL7b604cf1/ontoTools/inst/doc/sgdiOnto.Rnw"
## somod <- getSplits(omod)
## names(somod)


###################################################
### chunk number 13: lkmt eval=FALSE
###################################################
## #line 256 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmplGErpx/R.INSTALL7b604cf1/ontoTools/inst/doc/sgdiOnto.Rnw"
## somod$bysub$NCI_Meta_tag


###################################################
### chunk number 14: lkbc eval=FALSE
###################################################
## #line 261 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmplGErpx/R.INSTALL7b604cf1/ontoTools/inst/doc/sgdiOnto.Rnw"
## somod$bypred$NCI_Meta_tag


###################################################
### chunk number 15: lknom
###################################################
#line 275 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmplGErpx/R.INSTALL7b604cf1/ontoTools/inst/doc/sgdiOnto.Rnw"
data(SGDIvocab)
SGDIvocab

==> ontoTools_1.30.0.zip: ontoTools/doc/sgdiOnto.R <==
###################################################
### chunk number 1: 
###################################################
#line 88 "sgdiOnto.Rnw"
options(width=70)
require(ontoTools, quietly=TRUE)
library(KEGG.db)
#require(KEGG, quietly=TRUE)


###################################################
### chunk number 2: keggdemo
###################################################
#line 93 "sgdiOnto.Rnw"
KPL <- eapply(KEGGPATHID2NAME, function(x)x)
GDI_KEGGPATH <- new("nomenclature", name="KEGGPATH",
 provenance=new("provStruct", 
 URI="ftp://ftp.genome.ad.jp/pub/kegg/pathways/map_title.tab", 
 captureDate="June 30 2004", comment="Rel 30.0"), 
 inMappings=c("LL2KEGGmap.hsa", "LL2KEGGmap.rno"),
 terms=names(KPL), definitions=as.character(unlist(KPL)))
GDI_KEGGPATH


###################################################
### chunk number 3: lkGDINCI
###################################################
#line 129 "sgdiOnto.Rnw"
data(GDI_NCIThesaurus)
GDI_NCIThesaurus


###################################################
### chunk number 4: lkpar
###################################################
#line 135 "sgdiOnto.Rnw"
mpar <- parents("Mesna", GDI_NCIThesaurus)
mpar
children( mpar, GDI_NCIThesaurus )


###################################################
### chunk number 5: lkHER
###################################################
#line 141 "sgdiOnto.Rnw"
substring(grep("HER-2", GDI_NCIThesaurus),1,70)


###################################################
### chunk number 6: lkdef
###################################################
#line 145 "sgdiOnto.Rnw"
getDefs("Mesna", GDI_NCIThesaurus)


###################################################
### chunk number 7: 
###################################################
#line 178 "sgdiOnto.Rnw"
data(SGDIvocab)
SGDIvocab@terms


###################################################
### chunk number 8: loadRswub eval=FALSE
###################################################
## #line 224 "sgdiOnto.Rnw"
## library(Rswub)


###################################################
### chunk number 9: useRswub eval=FALSE
###################################################
## #line 226 "sgdiOnto.Rnw"
## omod <- readSWModel("http://www.biostat.harvard.edu/~carey/SGDI.owl", asURL=TRUE)


###################################################
### chunk number 10: local eval=FALSE
###################################################
## #line 228 "sgdiOnto.Rnw"
## omod <- readSWModel("/home/stvjc/Protege_3.0_beta/SGDI.owl")
## omod@documentName <- "http://www.biostat.harvard.edu/~carey/SGDI.owl"


###################################################
### chunk number 11: lkmod eval=FALSE
###################################################
## #line 232 "sgdiOnto.Rnw"
## omod


###################################################
### chunk number 12: lkont eval=FALSE
###################################################
## #line 250 "sgdiOnto.Rnw"
## somod <- getSplits(omod)
## names(somod)


###################################################
### chunk number 13: lkmt eval=FALSE
###################################################
## #line 256 "sgdiOnto.Rnw"
## somod$bysub$NCI_Meta_tag


###################################################
### chunk number 14: lkbc eval=FALSE
###################################################
## #line 261 "sgdiOnto.Rnw"
## somod$bypred$NCI_Meta_tag


###################################################
### chunk number 15: lknom
###################################################
#line 275 "sgdiOnto.Rnw"
data(SGDIvocab)
SGDIvocab
